@@ -26,6 +26,8 @@ def mol_enh(vapor_size, particle_size):
     a_q = in_length(vapor_size)
     b_q = in_length(particle_size)
 
-    return np.transpose(
-        (np.transpose([a_q.m])*a_q.u + b_q) / (b_q)
-    )**2
+    return np.reshape(
+        np.transpose(
+            (np.transpose([a_q.m])*a_q.u + b_q) / (b_q)
+        )**2, (b_q.size, a_q.size)
+    )
